//
// nono
// Copyright (C) 2022 nono project
// Licensed under nono-license.txt
//

//
// ROM 種別を表示するウィンドウ
//

#pragma once

#include "wxmonitor.h"
#include "wxtextscreen.h"

class WXROMWindow : public WXSubWindow
{
	using inherited = WXSubWindow;

 public:
	explicit WXROMWindow(wxWindow *parent);
	~WXROMWindow() override;
};
